# Copyright (C) Eugene Zamriy <ezamriy@msvsphere.ru>

# This file is part of the sos project: https://github.com/sosreport/sos
#
# This copyrighted material is made available to anyone wishing to use,
# modify, copy, or redistribute it subject to the terms and conditions of
# version 2 of the GNU General Public License.
#
# See the LICENSE file in the source distribution for further information.

from sos.policies.distros.redhat import RedHatPolicy, OS_RELEASE
import os


class MSVSpherePolicy(RedHatPolicy):

    distro = 'MSVSphere'

    vendor = 'LLC "NCSD"'

    vendor_urls = [
        ('Distribution Website', 'https://msvsphere.ru'),
        ('Vendor Website', 'http://ncpr.su/')
    ]

    @classmethod
    def check(cls, remote=''):
        if remote:
            return cls.distro in remote
        elif not os.path.exists(OS_RELEASE):
            return False
        with open(OS_RELEASE, 'r') as fd:
            for line in fd:
                if line.startswith('NAME') and 'MSVSphere' in line:
                    return True
        return False
